==> haskell-yaml-0.11.11.2-197-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yaml
version:              0.11.11.2
visibility:           public
id:                   yaml-0.11.11.2-CS9jj0skP8B8obc9v5e4bH
key:                  yaml-0.11.11.2-CS9jj0skP8B8obc9v5e4bH
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>

category:             Data
abi:                  d7e8d73bb87031d5ea55ffa360d63541
exposed:              True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH

hidden-modules:       Paths_yaml
import-dirs:          /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yaml
hs-libraries:         HSyaml-0.11.11.2-CS9jj0skP8B8obc9v5e4bH
depends:
    aeson-2.1.2.1-JZeWX2s1eQL7Ta3HF3w6fW
    attoparsec-0.14.4-K96akOPZKYDKXaMIGNQXgm base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-JmvSlylEAqiI8LFhx2lxVp
    containers-0.6.7 directory-1.3.8.5 filepath-1.4.300.1
    libyaml-0.1.4-DLFcAkkr97YGTFvSWk4EMz mtl-2.3.1
    resourcet-1.2.6-6GDX0mNNFVQIZmMacsito5
    scientific-0.3.8.0-7SlgUkp6kxxBFUUY5SNCvh template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-8SON4238u8N3rDHPceHjHx
    vector-0.13.2.0-JoP5POFPMLsLn1of7TvjGI

haddock-interfaces:   /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html:         /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yaml-0.11.11.2-198-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yaml
version:              0.11.11.2
visibility:           public
id:                   yaml-0.11.11.2-9quCwX1yndE4hP4rvoY2SV
key:                  yaml-0.11.11.2-9quCwX1yndE4hP4rvoY2SV
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>

category:             Data
abi:                  9b7f5893c407c8cfee776d5b2e6132df
exposed:              True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH

hidden-modules:       Paths_yaml
import-dirs:          /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yaml
hs-libraries:         HSyaml-0.11.11.2-9quCwX1yndE4hP4rvoY2SV
depends:
    aeson-2.1.2.1-6DouAcLayfd1cKsM4PdlxR
    attoparsec-0.14.4-IEX5Q72xfrMFJKDYkhuhWv base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-IACzArib6WtLejx9Lk1hSM
    containers-0.6.7 directory-1.3.8.5 filepath-1.4.300.1
    libyaml-0.1.4-D5nASUFft6U6X0u0eXrOED mtl-2.3.1
    resourcet-1.2.6-HW1njfedMilBzSD7euG5nt
    scientific-0.3.8.0-JLcC8H5zZSyDPbVdOVmQEk template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-650icVWmHjf3WKXK0GKpae
    vector-0.13.2.0-8Ien1418VpU5tGTMA2qRu7

haddock-interfaces:   /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html:         /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
